@@ -39,6 +39,10 @@ pub fn merge_json(a: &mut serde_json::Value, b: serde_json::Value) {
                     let mut _a = a.get(&k).unwrap().as_array().unwrap().to_owned();
                     _a.append(&mut v.as_array().unwrap().to_owned());
                     a[&k] = serde_json::Value::from(_a);
+                } else if v.is_u64() && a.contains_key(&k) && a.get(&k).as_ref().unwrap().is_u64() {
+                    let _a = a.get(&k).unwrap().as_u64().unwrap().to_owned();
+                    let _v = v.as_u64().unwrap().to_owned();
+                    a[&k] = serde_json::Value::from(_a + _v);
                 } else {
                     merge_json(a.entry(k).or_insert(serde_json::Value::Null), v);
                 }
